@@ -17,13 +17,13 @@
 import os
 import shlex
 import shutil
-from datetime import datetime
 from gettext import gettext as _
-from glob import glob
 from typing import Optional
 
 import icoextract  # type: ignore [import-untyped]
 
+from bottles.backend.params import APP_ID
+
 from bottles.backend.globals import Paths
 from bottles.backend.logger import Logger
 from bottles.backend.models.config import BottleConfig
@@ -32,6 +32,10 @@ from bottles.backend.state import SignalManager, Signals
 from bottles.backend.utils.generic import get_mime
 from bottles.backend.utils.imagemagick import ImageMagickUtils
 
+from gi.repository import GLib, Gio, Xdp
+
+portal = Xdp.Portal()
+
 logging = Logger()
 
 
@@ -223,22 +227,9 @@ class ManagerUtils:
         program: dict,
         skip_icon: bool = False,
         custom_icon: str = "",
-        use_xdp: bool = False,
-    ) -> bool:
-        if not use_xdp:
-            try:
-                os.makedirs(Paths.applications, exist_ok=True)
-            except OSError:
-                return False
-
-        cmd_legacy = "bottles"
-        cmd_cli = "bottles-cli"
+    ):
         icon = "com.usebottles.bottles-program"
 
-        if "FLATPAK_ID" in os.environ:
-            cmd_legacy = "flatpak run com.usebottles.bottles"
-            cmd_cli = "flatpak run --command=bottles-cli com.usebottles.bottles"
-
         if not skip_icon and not custom_icon:
             icon = ManagerUtils.extract_icon(
                 config, program.get("name"), program.get("path")
@@ -246,78 +237,43 @@ class ManagerUtils:
         elif custom_icon:
             icon = custom_icon
 
-        if not use_xdp:
-            file_name_template = "%s/%s--%s--%s.desktop"
-            existing_files = glob(
-                file_name_template
-                % (Paths.applications, config.Name, program.get("name"), "*")
+        def prepare_install_cb (self, result):
+            ret = portal.dynamic_launcher_prepare_install_finish(result)
+            id = f"{config.get('Name')}.{program.get('name')}"
+            sum_type = GLib.ChecksumType.SHA1
+            exec = "bottles-cli run -p {} -b '{}' -- %u".format(
+                shlex.quote(program.get('name')), config.get('Name')
             )
-            desktop_file = file_name_template % (
-                Paths.applications,
-                config.Name,
-                program.get("name"),
-                datetime.now().timestamp(),
-            )
-
-            if existing_files:
-                for file in existing_files:
-                    os.remove(file)
-
-            # [Bug-]issue #4247 (single- to double-quotes in Desktop Entry spec -> "The Exec key"):
-            with open(desktop_file, "w") as f:
-                f.write("[Desktop Entry]\n")
-                f.write(f"Name={program.get('name')}\n")
-                f.write(
-                    f"Exec={cmd_cli} run -p \"{program.get('name')}\" -b \"{config.get('Name')}\" -- %u\n"
+            portal.dynamic_launcher_install(
+                ret["token"],
+                "{}.App_{}.desktop".format(
+                    APP_ID, GLib.compute_checksum_for_string(sum_type, id, -1)
+                ),
+                """[Desktop Entry]
+                Exec={}
+                Type=Application
+                Terminal=false
+                Categories=Application;
+                Comment=Launch {} using Bottles.
+                StartupWMClass={}""".format(
+                    exec, program.get("name"), program.get("name")
                 )
-                f.write("Type=Application\n")
-                f.write("Terminal=false\n")
-                f.write("Categories=Application;\n")
-                f.write(f"Icon={icon}\n")
-                f.write(f"Comment=Launch {program.get('name')} using Bottles.\n")
-                f.write(f"StartupWMClass={program.get('name')}\n")
-                # Actions
-                f.write("Actions=Configure;\n")
-                f.write("[Desktop Action Configure]\n")
-                f.write("Name=Configure in Bottles\n")
-                f.write(f"Exec={cmd_legacy} -b \"{config.get('Name')}\"\n")
+            )
+            SignalManager.send(Signals.DesktopEntryCreated)
 
-            return True
-        '''
-        WIP: the following code is not working yet, it raises an error:
-             GDBus.Error:org.freedesktop.DBus.Error.UnknownMethod
-        import uuid
-        from gi.repository import Gio, Xdp
-
-        portal = Xdp.Portal()
         if icon == "com.usebottles.bottles-program":
-            _icon = Gio.BytesIcon.new(icon.encode("utf-8"))
+            icon += ".svg"
+            _icon = Gio.File.new_for_uri(
+                f"resource:/com/usebottles/bottles/icons/scalable/apps/{icon}"
+            )
         else:
-            _icon = Gio.FileIcon.new(Gio.File.new_for_path(icon))
-        icon_v = _icon.serialize()
-        token = portal.dynamic_launcher_request_install_token(program.get("name"), icon_v)
-        portal.dynamic_launcher_install(
-            token,
-            f"com.usebottles.bottles.{config.get('Name')}.{program.get('name')}.{str(uuid.uuid4())}.desktop",
-            """
-            [Desktop Entry]
-            Exec={}
-            Type=Application
-            Terminal=false
-            Categories=Application;
-            Comment=Launch {} using Bottles.
-            Actions=Configure;
-            [Desktop Action Configure]
-            Name=Configure in Bottles
-            Exec={}
-            """.format(
-                f"{cmd_cli} run -p {shlex.quote(program.get('name'))} -b '{config.get('Path')}'",
-                program.get("name"),
-                f"{cmd_legacy} -b '{config.get('Name')}'"
-            ).encode("utf-8")
-        )
-        '''
-        return False
+            _icon = Gio.File.new_for_path(icon)
+        icon_v = Gio.BytesIcon.new(_icon.load_bytes()[0]).serialize()
+        portal.dynamic_launcher_prepare_install(None,
+                                                program.get("name"), icon_v,
+                                                Xdp.LauncherType.APPLICATION,
+                                                None, True, False, None,
+                                                prepare_install_cb)
 
     @staticmethod
     def browse_wineprefix(wineprefix: dict):
