@@ -342,19 +342,20 @@ class WineCommand:
             ]
             gst_libs = ["lib/gstreamer-1.0", "lib32/gstreamer-1.0"]
 
-        for lib in runner_libs:
-            _path = os.path.join(runner_path, lib)
-            if os.path.exists(_path):
-                ld.append(_path)
+        if not config.Runner.startswith("sys-"):
+            for lib in runner_libs:
+                _path = os.path.join(runner_path, lib)
+                if os.path.exists(_path):
+                    ld.append(_path)
 
-        # Embedded GStreamer environment variables
-        if not env.has("BOTTLES_USE_SYSTEM_GSTREAMER") and not return_steam_env:
-            gst_env_path = []
-            for lib in gst_libs:
-                if os.path.exists(os.path.join(runner_path, lib)):
-                    gst_env_path.append(os.path.join(runner_path, lib))
-            if len(gst_env_path) > 0:
-                env.add("GST_PLUGIN_SYSTEM_PATH", ":".join(gst_env_path), override=True)
+            # Embedded GStreamer environment variables
+            if not env.has("BOTTLES_USE_SYSTEM_GSTREAMER") and not return_steam_env:
+                gst_env_path = []
+                for lib in gst_libs:
+                    if os.path.exists(os.path.join(runner_path, lib)):
+                        gst_env_path.append(os.path.join(runner_path, lib))
+                if len(gst_env_path) > 0:
+                    env.add("GST_PLUGIN_SYSTEM_PATH", ":".join(gst_env_path), override=True)
 
         # DXVK environment variables
         if params.dxvk and not return_steam_env:
@@ -445,13 +446,6 @@ class WineCommand:
         # if params["aco_compiler"]:
         #     env.add("ACO_COMPILER", "aco")
 
-        # FSR
-        if params.fsr:
-            env.add("WINE_FULLSCREEN_FSR", "1")
-            env.add("WINE_FULLSCREEN_FSR_STRENGTH", str(params.fsr_sharpening_strength))
-            if params.fsr_quality_mode:
-                env.add("WINE_FULLSCREEN_FSR_MODE", str(params.fsr_quality_mode))
-
         # PulseAudio latency
         if params.pulseaudio_latency:
             env.add("PULSE_LATENCY_MSEC", "60")
@@ -688,6 +682,8 @@ class WineCommand:
             gamescope_cmd = [gamescope_available]
             if return_steam_cmd:
                 gamescope_cmd = ["gamescope"]
+            if params.gamescope_custom_options:
+                gamescope_cmd.append(params.gamescope_custom_options)
             if params.gamescope_fullscreen:
                 gamescope_cmd.append("-f")
             if params.gamescope_borderless:
@@ -696,10 +692,8 @@ class WineCommand:
                 gamescope_cmd.append("-S integer")
             if params.fsr:
                 gamescope_cmd.append("-F fsr")
-                # Upscaling sharpness is from 0 to 20. There are 5 FSR upscaling levels,
-                # so multiply by 4 to reach 20
                 gamescope_cmd.append(
-                    f"--fsr-sharpness {params.fsr_sharpening_strength * 4}"
+                    f"--fsr-sharpness {params.fsr_sharpening_strength}"
                 )
             if params.gamescope_fps > 0:
                 gamescope_cmd.append(f"-r {params.gamescope_fps}")
